@@ -9,6 +9,9 @@ import pprint
 import re
 import translationstring
 import warnings
+import types
+
+from iso8601 import iso8601
 
 from .compat import (
     text_,
@@ -18,8 +21,6 @@ from .compat import (
     is_nonstr_iter,
     )
 
-from . import iso8601
-
 _ = translationstring.TranslationStringFactory('colander')
 
 class _required(object):
@@ -1578,7 +1579,11 @@ class GlobalObject(SchemaType):
             return null
 
         try:
-            return appstruct.__name__
+            if isinstance(appstruct, types.ModuleType):
+                return appstruct.__name__
+            else:
+                return '{0.__module__}.{0.__name__}'.format(appstruct)
+            
         except AttributeError:
             raise Invalid(node,
                           _('"${val}" has no __name__',
@@ -1922,7 +1927,13 @@ class _SchemaNode(object):
     - ``widget``: The 'widget' for this node.  Defaults to ``None``.
       The widget attribute is not interpreted by Colander itself, it
       is only meaningful to higher-level systems such as Deform.
-
+    
+    - ``insert_before``: if supplied, it names a sibling defined by a 
+      superclass for its parent node; the current node will be inserted 
+      before the named node. It is not useful unless a mapping schema is 
+      inherited from another mapping schema, and you need to control 
+      the ordering of the resulting nodes.
+      
     Arbitrary keyword arguments remaining will be attached to the node
     object unmolested.
     """
